@@ -1,11 +1,11 @@
 import os
-
-from element import Element
-os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
 import sys, pygame
 
 class Pygame:
     def __init__(self, backgroundImage, size : tuple or list, windowCaption = "Pygame", fps = 60, backgroundColour = (0, 0, 0), backgroundSound = None):
+        
+        os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
+        
         pygame.init()
 
         self.size = self.width, self.height = size
@@ -73,7 +73,7 @@ class Pygame:
     def loop(self, loop):
         self.main = loop
     
-    def addKeyboardMovement(self, element : Element, amount, up, down, left, right, stayInBounds = True):
+    def addKeyboardMovement(self, element, amount, up, down, left, right, stayInBounds = True):
         if not self.movingElement:
             self.movementAmount = amount
             self.keyboardEnabled = True
